"""
Utility for sending mail via SMTP.
"""

import sys 
import smtplib
import email

from email.Header import Header
from email.Utils import parseaddr, formataddr

def sendmail(sender, recipient, subject, body, smtp_host="localhost"):
    """ 
    Sends a generic email report.

    All arguments should be Unicode strings; if not, they will be converted into
    Unicode with the UTF-8 encoding. The final charset of the email is the first
    of US-ASCII, ISO-8859-1 and UTF-8 that can represent all the characters
    occurring in the email.
    """
    # Character set for the header - falls back to UTF-8 if it fails
    header_charset = "ISO-8859-1"

    # Apparently this is the best way to find the body charset
    for body_charset in ["US-ASCII", "ISO-8859-1", "UTF-8"]:
        try:
            body.encode(body_charset)
        except UnicodeError:
            pass
        else:
            break

    # Parse names in the correct character set (addresses must be ASCII)
    sender_name, sender_addr = parseaddr(sender)
    sender_name = str(Header(unicode(sender_name), header_charset))
    recipient_name, recipient_addr = parseaddr(recipient)
    recipient_name = str(Header(unicode(recipient_name), header_charset))

    # Message composition
    msg = email.MIMEText.MIMEText(body.encode(body_charset), "plain",
                                  body_charset)
    msg["From"] = formataddr((sender_name, sender_addr))
    msg["To"] = formataddr((recipient_name, recipient_addr))
    msg["Subject"] = Header(unicode(subject), header_charset)

    # Finally, send the message
    server = smtplib.SMTP(smtp_host)
    server.set_debuglevel(1)
    smtplib.stderr = sys.stdout
    server.sendmail(sender, recipient, msg.as_string())
    server.quit()


def sendspam(app, subject, body, scriptname="sendmail"):
    """ 
    Sends a Rutgers Repository Tools report via email.
    """
    msgbody = u"""
{0}

{1}
This report generated by {2}, a proud member of the Rutgers
Repository Tools family.

For more information, see https://github.com/oss/rutgers-repotools.
""".format(body, "-"*79, scriptname)

    try:
        sendmail(unicode(app.config.get("report", "from_addr")),
                 unicode(app.config.get("report", "to_addr")),
                 unicode(subject),
                 msgbody,
                 smtp_host=app.config.get("report", "smtp_host"))
    except Exception, e:
        app.logger.error("Sending mail failed: " + str(e))
